@@ -1,11 +1,12 @@
 /* AstroChart.m
  * The circular Astrology chart
  *
- * Copyright (C) 1998-2011 by vhf interservice GmbH
+ * Copyright (C) 1998-2012 by vhf interservice GmbH
  * Author:   Georg Fleischmann
  *
  * created:  1998-12-19
- * modified: 2011-04-22 (modulo chart)
+ * modified: 2012-08-16 (use [Document scale:scaleSize ...])
+ *           2011-04-22 (modulo chart)
  *           2010-01-17 (-radix:...: scale chart to fit window)
  *           2009-04-01 (radix: no date: draw composite only)
  *
@@ -34,6 +35,7 @@
 #include "../Cenon/functions.h"
 #include "../Cenon/Graphics.h"
 #include "../Cenon/DocWindow.h"
+#include "../Cenon/Document.h"
 #include "VTextAstroAdditions.h"	// convenient text methods
 #include "DocViewAstro.h"
 #include "AstroPrincipal.h"
@@ -1622,7 +1624,8 @@ typedef enum
  *   DATE
  *   TIME_#	time text for interval chart, optinally with interval (-#, +# in minutes)
  *
- * modified: 2010-04-22 (scale)
+ * modified: 2012-08-16 (scaleSize)
+ *           2010-04-22 (scale)
  */
 - (ChartTemplate)chartTemplate
 {
@@ -1637,11 +1640,12 @@ typedef enum
     /* Scale chart to fit window size */
     if ( ! [(DocWindow*)[view window] hasCoordDisplay] )
     {   NSRect  bounds = [view bounds], frame = [[view window] frame];
-        float   oldScale = [view scaleFactor];
-        float   scale = (frame.size.width / bounds.size.width) / oldScale;
+        VFloat  oldScale = [view scaleFactor];
+        NSSize  scaleSize;
 
-        if ( Diff(scale, 1.0) > TOLERANCE )
-            [[view document] scale:scale :scale withCenter:NSZeroPoint];
+        scaleSize.width = scaleSize.height = (frame.size.width  / bounds.size.width) / oldScale;
+        if ( Diff(scaleSize.width, 1.0) > TOLERANCE )
+            [[view document] scale:scaleSize withCenter:NSZeroPoint];
     }
 
     chartTemplate.center = NSZeroPoint;
@@ -1817,7 +1821,8 @@ typedef enum
 }
 
 /* main calculation method
- * modified: 2010-01-17 (scale to fit window)
+ * modified: 2012-08-16
+ *           2010-01-17 (scale to fit window)
  *           2009-04-01 (date = nil -> still draw composite)
  */
 - (void)radix:(NSCalendarDate*)date
@@ -1841,10 +1846,11 @@ typedef enum
     /* scale to fit window */
     if ( ! [(DocWindow*)[view window] hasCoordDisplay] )
     {   NSRect  bounds = [view bounds], frame = [[view window] frame];
-        float   oldScale = [view scaleFactor];
-        float   scale = (frame.size.width / bounds.size.width) / oldScale;
+        VFloat  oldScale = [view scaleFactor];
+        NSSize  scaleSize;
 
-        [[view document] scale:scale :scale withCenter:NSZeroPoint];
+        scaleSize.width = scaleSize.height = (frame.size.width  / bounds.size.width) / oldScale;
+        [[view document] scale:scaleSize withCenter:NSZeroPoint];
     }
 
     //[NSBezierPath setDefaultLineWidth:(VHFIsDrawingToScreen() ? 1.0/[view scaleFactor] : 0.1)];   // pointless, because this is not being saved
@@ -1864,7 +1870,7 @@ typedef enum
     /* get positions
      */
     if ([layerList count] <= 1)		// no way
-    {   NSLog(@"Not enough layers (%d) to calculate chart !", [layerList count]);
+    {   NSLog(@"Not enough layers (%lu) to calculate chart !", [layerList count]);
         return;
     }
     else if ([layerList count] == 2)	// use defaults
