@@ -1,10 +1,10 @@
 /* APMap.h
  *
- * Copyright (C) 2001-2003 by vhf interservice GmbH
+ * Copyright (C) 2001-2006 by vhf interservice GmbH
  * Author: Georg Fleischmann
  *
  * Created:  2001-05-18
- * Modified: 2003-07-22
+ * Modified: 2006-02-20
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the vhf Public License as
@@ -31,22 +31,34 @@
 #include <AppKit/AppKit.h>
 #include "APBasicLevel.h"
 
-#define SWITCH_SHOWACMC		0
-#define SWITCH_SHOWHOUSES	1
-#define SWITCH_SHOWZODIAC	2
-#define SWITCH_SHOWDEGREES	3
+typedef enum
+{
+    SWITCH_SHOWACMC    = 0,	// show AC, MC lines to objects
+    SWITCH_SHOWHOUSES  = 1,	// show house tips
+    SWITCH_SHOWZODIAC  = 2,
+    SWITCH_SHOWDEGREES = 3,
+    SWITCH_SHOWTRACKS  = 4	// show time tracks of objects
+}MapShowSwitches;
 
-#define SWITCH_CLICKCHART	0
-#define SWITCH_CLICKINFO	1
+typedef enum
+{
+    SWITCH_CLICKCHART  = 0,	// update Astro Chart
+    SWITCH_CLICKINFO   = 1	// show info for location and time
+}MapClickSwitches;
 
 @interface APMap:APBasicLevel
 {
     id	regionPopup;
     id	gridPopup;
     id	degreePopup;
+    id	objectPopup;
     id	clickSwitches;
     id	showSwitches;
+    id	earthSwitch;	// wheather to show earth revolution or skip days
+    id	dateFrField;	// for time tracks
+    id	dateToField;	// for time tracks
 
+    NSArray		*objectList;	// list of item names in object popups
     NSMutableDictionary	*mapDict;
 }
 
