@@ -1,11 +1,11 @@
 /* AstroPrincipal.m
  * Commander of the Astrology module
  *
- * Copyright (C) 2003-2010 by Georg Fleischmann
+ * Copyright (C) 2003-2012 by Georg Fleischmann
  * Author:   Georg Fleischmann
  *
  * created:  2003-03-29
- * modified: 2010-05-22
+ * modified: 2012-08-15
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the vhf Public License as
@@ -391,7 +391,8 @@ NSString *stringFromDeg(float deg)
 
 
 /* notification that a new document has been opened
- * modified: 2010-04-22 (Map fixed)
+ * modified: 2012-08-15 (scaleSize)
+ *           2010-04-22 (Map fixed)
  *           2010-01-17 (remove scroller for Chart and scale to window size)
  */
 - (void)documentDidOpen:(NSNotification*)notification
@@ -427,15 +428,16 @@ NSString *stringFromDeg(float deg)
 
             /* scale to fit window */
             {   NSRect  bounds = [view bounds], frame = [[view window] frame];
-                float   oldScale = [view scaleFactor];
-                float   scale = (frame.size.width / bounds.size.width) / oldScale;
+                VFloat   oldScale = [view scaleFactor];
+                NSSize   scaleSize;
 
-                [[view document] scale:scale :scale withCenter:NSZeroPoint];
+                scaleSize.width = scaleSize.height = (frame.size.width  / bounds.size.width) / oldScale;
+                [[view document] scale:scaleSize withCenter:NSZeroPoint];
             }
         }
     }
     else
-        NSLog(@"AstroPrincipal, notification send from object %@, shoult be DocView!", view);
+        NSLog(@"AstroPrincipal, notification send from object %@, should be DocView!", view);
 }
 
 /* notification that we have to calculate a chart (CalculateChartNotification)
